@@ -2,7 +2,7 @@ import inspect
 
 from guniflask.beans.errors import NoUniqueBeanDefinitionError, BeansError
 from guniflask.beans.factory import BeanFactory
-from guniflask.data_model.mapping import inspect_args, resolve_arg_type, ArgType
+from guniflask.data_model.typing import inspect_args, analyze_arg_type
 
 
 class ConstructorResolver:
@@ -31,22 +31,20 @@ class ConstructorResolver:
 
     def _resolve_arg(self, arg, required_type):
         bean = None
-        argc, etype = resolve_arg_type(required_type)
+        arg_ = analyze_arg_type(required_type)
 
-        if etype is None:
+        if arg_.outer_type is None:
             try:
                 bean = self._bean_factory.get_bean(arg)
             except BeansError:
                 pass
-        else:
-            candidates = self._bean_factory.get_beans_of_type(etype)
-            if argc is ArgType.DICT:
-                bean = candidates
-            elif argc is ArgType.LIST:
+        elif inspect.isclass(arg_.outer_type):
+            candidates = self._bean_factory.get_beans_of_type(arg_.outer_type)
+            if arg_.is_list():
                 bean = list(candidates.values())
-            elif argc is ArgType.SET:
+            elif arg_.is_set():
                 bean = set(candidates.values())
-            elif argc is ArgType.SINGLE:
+            elif arg_.is_singleton():
                 if len(candidates) == 1:
                     bean = list(candidates.values())[0]
                 elif len(candidates) > 1:
