@@ -3,5 +3,5 @@ from .app_settings import settings
 from .env import app_name_from_env
 from .env import load_app_env
 from .env import set_app_default_env
-from .loader import load_config
-from .loader import load_profile_config
+from .load_utils import load_app_settings
+from .load_utils import load_profile_config
