@@ -20,8 +20,10 @@ class ConfiguredSecurityBuilder(AbstractSecurityBuilder, metaclass=ABCMeta):
         if not configurers:
             return
         if len(configurers) != 1:
-            raise ValueError(f'Only one configurer excepted for type {configurer_type.__name__}, '
-                             f'but got {len(configurers)}')
+            raise ValueError(
+                f'Only one configurer excepted for type {configurer_type.__name__}, '
+                f'but got {len(configurers)}'
+            )
         return configurers[0]
 
     def apply(self, configurer: SecurityConfigurer):
